@@ -1,4 +1,5 @@
 import requests
+import re
 from typing import Callable, TypeVar, get_type_hints, Type
 import xwire.transport
 from xwire.common import decorator_utils
@@ -20,12 +21,19 @@ def _do_get(url: str, return_class: Type[T], **kwargs) -> T:
 
 
 def get(path: str):
+    path_params = re.findall(r':\w+', path)
+
     def decorator(func: Callable[..., T]) -> Callable[..., T]:
         return_type = get_type_hints(func)['return']
 
         def wrapper(self, *args):
             resource_metadata = decorator_utils.get_decorator_metadata(self, resource)
-            url = self.base_url + resource_metadata['resource_path'] + path
+
+            method_path = path
+            for path_param, arg in zip(path_params, args):
+                method_path = method_path.replace(path_param, str(arg))
+
+            url = self.base_url + resource_metadata['resource_path'] + method_path
             return _do_get(url, return_type, cookies=get_cookies(self))
 
         return wrapper
