@@ -1,6 +1,9 @@
 import requests
 from typing import Dict, Type, TypeVar, get_type_hints, Callable
-from xwire.rest._private.utils import deserialize, get_cookies
+import xwire.transport
+from xwire.common import decorator_utils
+from xwire.rest._private.proxy.decorators import resource
+from xwire.rest._private.utils import get_cookies
 
 T = TypeVar('T')
 
@@ -10,7 +13,7 @@ def _do_post(url: str, json: Dict[str, str], return_class: Type[T], **kwargs) ->
     if response.status_code >= 400:
         response.raise_for_status()
     elif return_class is not None:
-        return deserialize(response.json(), return_class)
+        return xwire.transport.json.deserialize(response.json(), return_class)
     else:
         return None
 
@@ -20,9 +23,10 @@ def post(path: str):
         return_type = get_type_hints(func)['return']
 
         def wrapper(self, *args):
-            url = self.base_url + self._proxy['_resource_path'] + path
+            resource_metadata = decorator_utils.get_decorator_metadata(self, resource)
+            url = self.base_url + resource_metadata['resource_path'] + path
             body = args[0]
-            return _do_post(url, body.serialize(), return_type, cookies=get_cookies(self))
+            return _do_post(url, xwire.transport.json.serialize(body), return_type, cookies=get_cookies(self))
 
         return wrapper
-    return decorator
\ No newline at end of file
+    return decorator
